pub struct BundleVerificationContext { /* private fields */ }Expand description
Explicit capability, extension, scope, profile, and projection trust context.
Implementations
Sourceimpl BundleVerificationContext
impl BundleVerificationContext
Sourcepub fn new(
semantic_profile: SemanticProfileId,
managed_scope: ManagedScopeBinding,
available_capabilities: CapabilitySet,
available_extensions: impl IntoIterator<Item = ExtensionRequirement>,
projections: impl IntoIterator<Item = BundleProjectionContext>,
) -> Result<Self, SchemaBundleError>
pub fn new( semantic_profile: SemanticProfileId, managed_scope: ManagedScopeBinding, available_capabilities: CapabilitySet, available_extensions: impl IntoIterator<Item = ExtensionRequirement>, projections: impl IntoIterator<Item = BundleProjectionContext>, ) -> Result<Self, SchemaBundleError>
Construct a closed verification context without consulting sources or providers.
Sourcepub const fn available_capabilities(&self) -> &CapabilitySet
pub const fn available_capabilities(&self) -> &CapabilitySet
Return capabilities available to schema resolution and bundle consumption.
Sourcepub const fn available_extensions(&self) -> &BTreeSet<ExtensionRequirement>
pub const fn available_extensions(&self) -> &BTreeSet<ExtensionRequirement>
Return extensions available to bundle consumption.
Sourcepub const fn managed_scope(&self) -> &ManagedScopeBinding
pub const fn managed_scope(&self) -> &ManagedScopeBinding
Return the expected durable managed scope and frozen profile binding.
Sourcepub const fn semantic_profile(&self) -> &SemanticProfileId
pub const fn semantic_profile(&self) -> &SemanticProfileId
Return the expected semantic profile identity.
Sourcepub fn projection(
&self,
target: BindingTarget,
) -> Option<&BundleProjectionContext>
pub fn projection( &self, target: BindingTarget, ) -> Option<&BundleProjectionContext>
Look up exact projection verification policy by shipped target.