pub struct LocatedConfigSpec { /* private fields */ }Expand description
A strict config spec permanently bound to the manifest that owns its paths.
Implementations
Sourceimpl LocatedConfigSpec
impl LocatedConfigSpec
Sourcepub const fn origin(&self) -> &ConfigOrigin
pub const fn origin(&self) -> &ConfigOrigin
Return the immutable captured origin.
Sourcepub const fn spec(&self) -> &TypeBridgeConfigSpec
pub const fn spec(&self) -> &TypeBridgeConfigSpec
Return the lossless parsed spec.
Sourcepub fn resolve(
self,
services: &TypeBridgeConfigServices<'_>,
) -> Result<TypeBridgeConfig, WorkspaceConfigError>
pub fn resolve( self, services: &TypeBridgeConfigServices<'_>, ) -> Result<TypeBridgeConfig, WorkspaceConfigError>
Resolve solely through validated nested types and the existing builder.