pub struct ConfigOrigin { /* private fields */ }Expand description
An immutable source origin for one workspace manifest.
The manifest path is confined under the explicit workspace root. All wire paths are resolved relative to the manifest’s owning directory, never the process current directory.
Implementations
Sourceimpl ConfigOrigin
impl ConfigOrigin
Sourcepub fn new(
workspace_root: WorkspaceRoot,
manifest_path: impl Into<PathBuf>,
diagnostic_name: impl Into<String>,
) -> Result<Self, WorkspaceConfigError>
pub fn new( workspace_root: WorkspaceRoot, manifest_path: impl Into<PathBuf>, diagnostic_name: impl Into<String>, ) -> Result<Self, WorkspaceConfigError>
Construct a captured manifest origin under an explicit workspace root.
Sourcepub const fn workspace_root(&self) -> &WorkspaceRoot
pub const fn workspace_root(&self) -> &WorkspaceRoot
Return the explicit canonical workspace root.
Sourcepub fn manifest_path(&self) -> &Path
pub fn manifest_path(&self) -> &Path
Return the manifest path relative to the workspace root.
Sourcepub fn manifest_absolute_path(&self) -> PathBuf
pub fn manifest_absolute_path(&self) -> PathBuf
Return the manifest path resolved under the workspace root.
Sourcepub fn diagnostic_name(&self) -> &str
pub fn diagnostic_name(&self) -> &str
Return the immutable diagnostic origin name.