pub struct TypeBridgeConfigSpec { /* private fields */ }Expand description
A strict parsed workspace spec retaining exact source, comments, and spans.
The semantic wire is private and this trusted type implements no deserialization contract.
Implementations
Sourceimpl TypeBridgeConfigSpec
impl TypeBridgeConfigSpec
Sourcepub fn parse_yaml(
source: impl Into<String>,
origin: ConfigOrigin,
) -> Result<LocatedConfigSpec, WorkspaceConfigError>
pub fn parse_yaml( source: impl Into<String>, origin: ConfigOrigin, ) -> Result<LocatedConfigSpec, WorkspaceConfigError>
Parse UTF-8 workspace text and permanently attach its origin.
Sourcepub fn from_yaml_bytes(
bytes: &[u8],
origin: ConfigOrigin,
) -> Result<LocatedConfigSpec, WorkspaceConfigError>
pub fn from_yaml_bytes( bytes: &[u8], origin: ConfigOrigin, ) -> Result<LocatedConfigSpec, WorkspaceConfigError>
Parse exact file bytes as UTF-8 and permanently attach their origin.
Sourcepub fn comments(&self) -> &[SchemaComment]
pub fn comments(&self) -> &[SchemaComment]
Return retained source comments in parser order.
Sourcepub const fn fingerprint(&self) -> &DocumentFingerprint
pub const fn fingerprint(&self) -> &DocumentFingerprint
Return the exact authored-source fingerprint.
Sourcepub const fn root(&self) -> &YamlMapping
pub const fn root(&self) -> &YamlMapping
Return the lossless root mapping and its exact spans.